@@ -5,6 +5,10 @@
 
 /* The SVG backend of Potrace. */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <stdio.h>
 #include <stdarg.h>
 #include <string.h>
@@ -17,10 +21,6 @@
 #include "lists.h"
 #include "auxiliary.h"
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 /* ---------------------------------------------------------------------- */
 /* path-drawing auxiliary functions */
 
