@@ -1,10 +1,14 @@
-/* Copyright (C) 2001-2013 Peter Selinger.
+/* Copyright (C) 2001-2015 Peter Selinger.
    This file is part of Potrace. It is free software and it is covered
    by the GNU General Public License. See the file COPYING for details. */
 
 
 /* The xfig backend of Potrace. */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <stdio.h>
 #include <stdarg.h>
 #include <string.h>
@@ -17,10 +21,6 @@
 #include "auxiliary.h"
 #include "trans.h"
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #ifndef M_PI
 #define M_PI 3.14159265358979323846
 #endif
@@ -215,7 +215,7 @@ int page_xfig(FILE *fout, potrace_path_t *plist, imginfo_t *imginfo) {
 
   /* header */
   fprintf(fout, "#FIG 3.2\n");
-  fprintf(fout, "#created by "POTRACE" "VERSION", written by Peter Selinger 2001-2013\n");
+  fprintf(fout, "#created by "POTRACE" "VERSION", written by Peter Selinger 2001-2015\n");
   fprintf(fout, "Portrait\n");
   fprintf(fout, "Center\n");
   fprintf(fout, "Inches\n");
