@@ -16,7 +16,7 @@
 #define BITOPS_H
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
 /* ---------------------------------------------------------------------- */
