@@ -1,7 +1,11 @@
-/* Copyright (C) 2001-2013 Peter Selinger.
+/* Copyright (C) 2001-2015 Peter Selinger.
    This file is part of Potrace. It is free software and it is covered
    by the GNU General Public License. See the file COPYING for details. */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <stdlib.h>
 #include <string.h>
 
@@ -11,10 +15,6 @@
 #include "trace.h"
 #include "progress.h"
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 /* default parameters */
 static const potrace_param_t param_default = {
   2,                             /* turdsize */
