@@ -4,6 +4,10 @@
 
 /* transform jaggy paths into smooth curves */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <stdio.h>
 #include <math.h>
 #include <stdlib.h>
